unit uDBPoolTest;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  IBDatabasePool, StdCtrls, uDBThread, ComCtrls, ExtCtrls, Grids, Spin;

type
  TfrmTimeTest = class(TForm)
    StatusBar: TStatusBar;
    PageControl: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    bStartOne: TButton;
    bOpenAllDB: TButton;
    bCloseAllDB: TButton;
    bStopAll: TButton;
    bStopOne: TButton;
    sgTimes: TStringGrid;
    bClearAll: TButton;
    DBPool: TIBDatabasePool;
    QueryQueue: TIBQueryQueue;
    bRefreshTimes: TButton;
    seDBPoolMax: TSpinEdit;
    Label1: TLabel;
    seFactor: TSpinEdit;
    Label2: TLabel;
    eDBLoc: TEdit;
    Label3: TLabel;
    Label4: TLabel;
    eUsername: TEdit;
    Label5: TLabel;
    ePassword: TEdit;
    Label6: TLabel;
    mSQL: TMemo;
    seMgrs: TSpinEdit;
    Label7: TLabel;
    procedure bOpenAllDBClick(Sender: TObject);
    procedure bCloseAllDBClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure bStartOneClick(Sender: TObject);
    procedure bStopAllClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure bStopOneClick(Sender: TObject);
    procedure bClearAllClick(Sender: TObject);
    procedure bRefreshTimesClick(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
  private
    Lst : TThreadList;
 public
  end;

var
  frmTimeTest: TfrmTimeTest;

implementation

{$R *.DFM}

procedure TfrmTimeTest.bOpenAllDBClick(Sender: TObject);
begin
  StatusBar.SimpleText := 'Opeining All..';
  DBPool.DatabaseName := eDBLoc.Text;
  DBPool.MaxConnections := seDBPoolMax.Value;
  DBPool.Params.Values['USER_NAME'] := eUsername.Text;
  DBPool.Params.Values['PASSWORD'] := ePassword.Text;
  QueryQueue.MaxQueueFactor := seFactor.Value;
  QueryQueue.QueueManagers := seMgrs.Value;
  DBPool.OpenAll;
  StatusBar.SimpleText := 'Ready to begin threads.';
  bStartOne.Enabled := True;
  bCloseAllDB.Enabled := True;
end;

procedure TfrmTimeTest.bCloseAllDBClick(Sender: TObject);
begin
  StatusBar.SimpleText := 'Closing All...';
  DBPool.CloseAll;
  StatusBar.SimpleText := 'All Database Connections Closed.';
  bStartOne.Enabled := False;
  bStopOne.Enabled := False;
  bStopAll.Enabled := False;
  bCloseAllDB.Enabled := False;
end;

procedure TfrmTimeTest.FormCreate(Sender: TObject);
begin
  Lst := TThreadList.Create;
end;

procedure TfrmTimeTest.FormDestroy(Sender: TObject);
begin
  Lst.Free;
end;

procedure TfrmTimeTest.bStartOneClick(Sender: TObject);
begin
  Lst.Add(TDBThread.Create(QueryQueue, mSQL.Text));
  bStopOne.Enabled := True;
  bStopAll.Enabled := True;
  bCloseAllDB.Enabled := False;
  bOpenAllDB.Enabled := False;
end;

procedure TfrmTimeTest.bStopAllClick(Sender: TObject);
begin
  with Lst.LockList do
  try
    while Count >0 do
    begin
      TDBThread(Items[Count-1]).Terminate;
      TDBThread(Items[Count-1]).Free;
      Delete(Count-1);
    end;
  finally
    Lst.UnlockList;
  end;
  bStopOne.Enabled := False;
  bStopAll.Enabled := False;
  bCloseAllDB.Enabled := True;
  bOpenAllDB.Enabled := True;
end;

procedure TfrmTimeTest.FormShow(Sender: TObject);
begin
  PageControl.ActivePage := TabSheet1;
  sgTimes.ColWidths[0] := 50;
  sgTimes.ColWidths[1] := (sgTimes.Width-100) div 4;
  sgTimes.ColWidths[2] := (sgTimes.Width-100) div 4;
  sgTimes.ColWidths[3] := (sgTimes.Width-100) div 4;
  sgTimes.ColWidths[4] := (sgTimes.Width-100) div 4;
  sgTimes.ColWidths[5] := 50;
  sgTimes.Cells[0,0] := 'Thread #';
  sgTimes.Cells[1,0] := 'Current ms';
  sgTimes.Cells[2,0] := 'Average ms';
  sgTimes.Cells[3,0] := 'Minimum ms';
  sgTimes.Cells[4,0] := 'Maximum ms';
  sgTimes.Cells[5,0] := 'Executed';
end;

procedure TfrmTimeTest.bStopOneClick(Sender: TObject);
begin
  with Lst.LockList do
  try
    TDBThread(Items[Count-1]).Terminate;
    TDBThread(Items[Count-1]).Free;
    Delete(Count-1);
    if Count=0 then
    begin
      bStopOne.Enabled := False;
      bStopAll.Enabled := False;
      bCloseAllDB.Enabled := True;
      bOpenAllDB.Enabled := True;
    end;
  finally
    Lst.UnlockList;
  end;
end;

procedure TfrmTimeTest.bClearAllClick(Sender: TObject);
var
  i : integer;
begin
  try
    with Lst.LockList do
    try
      for i := 0 to Count-1 do
      begin
        TDBThread(Items[i]).ClearTimes;
      end;
    finally
      Lst.UnlockList;
    end;
  except
  end;
end;

procedure TfrmTimeTest.bRefreshTimesClick(Sender: TObject);
var
  i : integer;
begin
  try
    with Lst.LockList do
    try
      sgTimes.RowCount := Count+1;
      if Count >1 then
        sgTimes.FixedRows := 1;
      for i := 0 to Count-1 do
      begin
        sgTimes.Cells[0,i+1] := IntToStr(i);
        sgTimes.Cells[1,i+1] := FloatToStr(TDBThread(Items[i]).CurrentTime);
        sgTimes.Cells[2,i+1] := FloatToStr(TDBThread(Items[i]).AverageTime);
        sgTimes.Cells[3,i+1] := FloatToStr(TDBThread(Items[i]).MinimumTime);
        sgTimes.Cells[4,i+1] := FloatToStr(TDBThread(Items[i]).MaximumTime);
        sgTimes.Cells[5,i+1] := IntToStr(TDBThread(Items[i]).ExecuteCount);
      end;
    finally
      Lst.UnlockList;
    end;
  except
  end;
end;

procedure TfrmTimeTest.FormCloseQuery(Sender: TObject;
  var CanClose: Boolean);
begin
  if bStopAll.Enabled then
    bStopAll.Click;
  if bCloseAllDB.Enabled then
    bCloseAllDB.Click;
end;

end.
