unit uDBThread;

interface

uses
  Classes, StdCtrls, SysUtils, IBDatabase, IBDatabasePool, IBQuery;

type
  TDBThread = class(TThread)
  private
    FExecuteCount : integer;
    FQQ : TIBQueryQueue;
    FMinimumTime: extended;
    FCurrentTime: extended;
    FMaximumTime: extended;
    FAverageTime: extended;
    SumTime : extended;
    SQLText : string;
  protected
    procedure Execute; override;
  public
    constructor Create(QQ : TIBQueryQueue; Text : string);
    property CurrentTime : extended read FCurrentTime;
    property AverageTime : extended read FAverageTime;
    property MaximumTime : extended read FMaximumTime;
    property MinimumTime : extended read FMinimumTime;
    property ExecuteCount : integer read FExecuteCount;
    procedure ClearTimes;
  end;

implementation

uses uDBPoolTest;

{ TDBThread }


procedure TDBThread.ClearTimes;
begin
  Suspend;
  try
    FExecuteCount := 0;
    FCurrentTime := 0;
    SumTime := 0;
    FMinimumTime := 9999999;
    FMaximumTime := 0;
    FAverageTime := 0;
  finally
    Resume;
  end;
end;

constructor TDBThread.Create(QQ: TIBQueryQueue; Text : string);
begin
  inherited Create(True);
  FQQ := QQ;
  SQLText := Text;
  ClearTimes;
  Resume;
end;

procedure TDBThread.Execute;
  procedure ConvertToMS(var Value : extended);
  begin
    Value := 5184000 * Value;
    Value := Value * 10000;
    Value := Round(Value);
    Value := Value / 10000;
  end;
var
  Query : TIBQuery;
  BeginTime, EndTime : extended;
begin
  while not Terminated do
  begin
    Priority := tpHigher;
    BeginTime := Time;
    Query := FQQ.OpenSQL(SQLText,True);
    try
      // Do something here.
    finally
      FQQ.CloseSQL(Query);
      EndTime := Time;
      Priority := tpLower;

      inc(FExecuteCount);
      FCurrentTime := EndTime-BeginTime;
      ConvertToMS(FCurrentTime);
      SumTime := SumTime+FCurrentTime;
      if FCurrentTime < FMinimumTime then
        FMinimumTime := FCurrentTime;
      if FCurrentTime > FMaximumTime then
        FMaximumTime := FCurrentTime;
      FAverageTime := SumTime / FExecuteCount;
      FAverageTime := FAverageTime * 10000;
      FAverageTime := Round(FAverageTime);
      FAverageTime := FAverageTime / 10000;
    end;
  end;
end;

end.
