unit GDIPlus;

interface

uses Windows;

const
    DLLName = 'gdiplus.dll';

// Brush styles

    bsBackwardDiagonal  = 0;
    bsCross             = 1;
    bsDiagonalCross     = 2;
    bsForwardDiagonal   = 3;
    bsHollow            = 4;
    bsHorizontal        = 5;
    bsPattern           = 6;
    bsSolid             = 7;
    bsVertical          = 8;

// Polygon fill modes

    Alternate           = 0;
    Winding             = 1;

type
    GPPointF = record
                   X, Y: Single;
               end;

    GPPointI = record
                   X, Y: Integer;
               end;

    GPRectF = record
                  X, Y, Width, Height: Single;
              end;

    GPRectI = record
                  X, Y, Width, Height: Integer;
              end;

function GdipCreateFromHDC (hdc: HDC; var Graphics: Integer): Integer; stdcall; external DLLName;
function GdipDeleteGraphics (Graphics: Integer): Integer; stdcall; external DLLName;

// Brushes

function GdipDeleteBrush (Brush: Integer): Integer; stdcall; external DLLName;
function GdipCreateSolidFill (Color: Cardinal; var Brush: Integer): Integer; stdcall; external DLLName;
function GdipCreateHatchBrush (HatchStyle: Integer; ForeCol, BackCol: Cardinal; var Brush: Integer): Integer; stdcall; external DLLName;
function GdipCreateTexture (Bitmap, WrapMode: Integer; var Texture: Integer): Integer; stdcall; external DLLName;
function GdipGetHatchStyle (Brush: Integer; var HatchStyle: Integer): Integer; stdcall; external DLLName;
function GdipGetBrushType (Brush: Integer; var BrushType: Integer): Integer; stdcall; external DLLName;
function GdipSetSolidFillColor (Brush: Integer; Color: Cardinal): Integer; stdcall; external DLLName;
function GdipGetSolidFillColor (Brush: Integer; var Color: Cardinal): Integer; stdcall; external DLLName;
function GdipCreatePathGradientFromPath (Path: Integer; var Brush: Integer): Integer; stdcall; external DLLName;
function GdipSetPathGradientCenterColor (Brush: Integer; Color: Cardinal): Integer; stdcall; external DLLName;

// Bitmaps

function GdipCreateBitmapFromGraphics (Width, Height, Graphics: Integer; var Bitmap: Integer): Integer; stdcall; external DLLName;

// Images

function GdipDisposeImage (Image: Integer): Integer; stdcall; external DLLName;

// Fills

function GdipFillRectangle (Graphics, Brush: Integer; x, y, Width, Height: Single): Integer; stdcall; external DLLName;
function GdipFillRectangleI (Graphics, Brush, x, y, Width, Height: Integer): Integer; stdcall; external DLLName;
function GdipFillRectangles (Graphics, Brush: Integer; var Rects: GPRectF; Count: Integer): Integer; stdcall; external DLLName;
function GdipFillRectanglesI (Graphics, Brush: Integer; var Rects: GPRectI; Count: Integer): Integer; stdcall; external DLLName;
function GdipFillEllipse (Graphics, Brush: Integer; x, y, Width, Height: Single): Integer; stdcall; external DLLName;
function GdipFillEllipseI (Graphics, Brush, x, y, Width, Height: Integer): Integer; stdcall; external DLLName;
function GdipFillPolygon (Graphics, Brush: Integer; var Points: GPPointF; Count, FillMode: Integer): Integer; stdcall; external DLLName;
function GdipFillPolygonI (Graphics, Brush: Integer; var Points: GPPointI; Count, FillMode: Integer): Integer; stdcall; external DLLName;
function GdipFillPolygon2 (Graphics, Brush: Integer; var Points: GPPointF; Count: Integer): Integer; stdcall; external DLLName;
function GdipFillPolygon2I (Graphics, Brush: Integer; var Points: GPPointI; Count: Integer): Integer; stdcall; external DLLName;
function GdipFillPie (Graphics, Brush: Integer; x, y, Width, Height, StartAngle, SweepAngle: Single): Integer; stdcall; external DLLName;
function GdipFillPieI (Graphics, Brush, x, y, Width, Height: Integer; StartAngle, SweepAngle: Single): Integer; stdcall; external DLLName;
function GdipFillPath (Graphics, Brush, Path: Integer): Integer; stdcall; external DLLName;

// Paths

function GdipCreatePath (FillMode: Integer; var Path: Integer): Integer; stdcall; external DLLName;
function GdipDeletePath (Path: Integer): Integer; stdcall; external DLLName;
function GdipDrawPath (Graphics, Pen, Path: Integer): Integer; stdcall; external DLLName;
function GdipAddPathLine (Path: Integer; x1, y1, x2, y2: Single): Integer; stdcall; external DLLName;
function GdipAddPathArc (Path: Integer; x, y, Width, Height, StartAngle, SweepAngle: Single): Integer; stdcall; external DLLName;
function GdipAddPathCurve (Path: Integer; var MemoryPts: GPPointF; Count: Integer): Integer; stdcall; external DLLName;
function GdipAddPathBeziers (Path: Integer; var MemoryPts: GPPointF; Count: Integer): Integer; stdcall; external DLLName;



function GdipCreateAdjustableArrowCap (Height, Width: Single; IsFilled: Bool; var adjustableArrowCap: Integer): Integer; stdcall; external DLLName;
function GdipSetAdjustableArrowCapHeight (adjustableArrowCap: Integer; Height: Single): Integer; stdcall; external DLLName;
function GdipGetAdjustableArrowCapHeight (adjustableArrowCap: Integer; var Height: Single): Integer; stdcall; external DLLName;

implementation

end.
